You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@beam.apache.org by al...@apache.org on 2019/03/26 00:41:37 UTC

[beam] 01/01: Correct flag name

This is an automated email from the ASF dual-hosted git repository.

altay pushed a commit to branch aaltay-patch-1
in repository https://gitbox.apache.org/repos/asf/beam.git

commit 9225c0bf3acf88041f05e8eb914e4e576ee2e71b
Author: Ahmet Altay <aa...@gmail.com>
AuthorDate: Mon Mar 25 17:41:20 2019 -0700

    Correct flag name
    
    Correct the flag name of enable_streaming_engine in the warning text.
---
 sdks/python/apache_beam/runners/dataflow/dataflow_runner.py | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/sdks/python/apache_beam/runners/dataflow/dataflow_runner.py b/sdks/python/apache_beam/runners/dataflow/dataflow_runner.py
index 957c903..e6895b1 100644
--- a/sdks/python/apache_beam/runners/dataflow/dataflow_runner.py
+++ b/sdks/python/apache_beam/runners/dataflow/dataflow_runner.py
@@ -377,9 +377,9 @@ class DataflowRunner(PipelineRunner):
         if ("enable_windmill_service" in debug_options.experiments
             or "enable_streaming_engine" in debug_options.experiments):
           raise ValueError("""Streaming engine both disabled and enabled:
           enableStreamingEngine is set to false, but enable_windmill_service
           and/or enable_streaming_engine are present. It is recommended you
-          only set enableStreamingEngine.""")
+          only set enable_streaming_engine flag.""")
 
     # TODO(BEAM-6664): Remove once Dataflow supports --dataflow_kms_key.
     if google_cloud_options.dataflow_kms_key is not None:
@@ -377,9 +377,9 @@ class DataflowRunner(PipelineRunner):
             or "enable_streaming_engine" in debug_options.experiments):
           raise ValueError("""Streaming engine both disabled and enabled:
-          enableStreamingEngine is set to false, but enable_windmill_service
+          enable_streaming_engine flag is not set, but enable_windmill_service
           and/or enable_streaming_engine are present. It is recommended you